aboutsummaryrefslogtreecommitdiffhomepage
path: root/lib/maths-menu.el
diff options
context:
space:
mode:
authorGravatar David Aspinall <da@inf.ed.ac.uk>2008-01-28 19:17:26 +0000
committerGravatar David Aspinall <da@inf.ed.ac.uk>2008-01-28 19:17:26 +0000
commit6175adcd92ea0f04003d6a6cefd3257743d68b2a (patch)
tree6eac4789e32f7e26cb79b45f6ad3dfaff8513bcf /lib/maths-menu.el
parent3c8465b3606e33b0324b51250da5bec6f230f739 (diff)
Maths menu works OK in Carbon Emacs
Diffstat (limited to 'lib/maths-menu.el')
-rw-r--r--lib/maths-menu.el6
1 files changed, 4 insertions, 2 deletions
diff --git a/lib/maths-menu.el b/lib/maths-menu.el
index 9e308faa..365a790a 100644
--- a/lib/maths-menu.el
+++ b/lib/maths-menu.el
@@ -316,9 +316,11 @@
:help "Menu of maths characters to insert"))
map))
;; Unless we have Gtk menus, we probably can't display the maths
;; correctly in the menu bar.
-(unless (string-match "--with-gtk" system-configuration-options)
+(unless
+ (or (string-match "--with-gtk" system-configuration-options)
+ (string-match "--with-carbon" system-configuration-options))
(define-key-after maths-menu-menu [warnl] '(menu-item "--"))
(define-key-after maths-menu-menu [warn1]
'(menu-item "NB. This Emacs displays"))
@@ -316,9 +316,11 @@
:help "Menu of maths characters to insert"))
map))
-;; Unless we have Gtk menus, we probably can't display the maths
+;; Unless we have Gtk/Carbon menus, we probably can't display the maths
;; correctly in the menu bar.